==> mono-2.4.3.tar.bz2: mono-2.4.3/mcs/class/System/System.Net.Configuration/PerformanceCountersElement.cs <==
//
// System.Net.Configuration.PerformanceCountersElement
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//
// (C) 2005 Novell, Inc. (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0 && CONFIGURATION_DEP

using System;
using System.Configuration;

namespace System.Net.Configuration {

        public sealed class PerformanceCountersElement : ConfigurationElement
        {
                static ConfigurationProperty enabledProp;
                static ConfigurationPropertyCollection properties;

                static PerformanceCountersElement ()
                {
                        enabledProp = new ConfigurationProperty ("enabled", typeof (bool), false);
                        properties = new ConfigurationPropertyCollection ();

                        properties.Add (enabledProp);

                }

                [ConfigurationProperty ("enabled", DefaultValue = "False")]
                public bool Enabled {
                        get { return (bool) base [enabledProp];}
                        set { base[enabledProp] = value; }
                }

                protected override ConfigurationPropertyCollection Properties {
                        get { return properties; }
                }

        }

}

#endif

==> mono-4.4.0.148.tar.bz2: mono-4.4.0/mcs/class/System/System.Net.Configuration/PerformanceCountersElement.cs <==
//
// System.Net.Configuration.PerformanceCountersElement
//
// Authors:
//	Chris Toshok (toshok@ximian.com)
//
// (C) 2005 Novell, Inc. (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if CONFIGURATION_DEP

using System;
using System.Configuration;

namespace System.Net.Configuration {

        public sealed class PerformanceCountersElement : ConfigurationElement
        {
                static ConfigurationProperty enabledProp;
                static ConfigurationPropertyCollection properties;

                static PerformanceCountersElement ()
                {
                        enabledProp = new ConfigurationProperty ("enabled", typeof (bool), false);
                        properties = new ConfigurationPropertyCollection ();

                        properties.Add (enabledProp);

                }

                [ConfigurationProperty ("enabled", DefaultValue = "False")]
                public bool Enabled {
                        get { return (bool) base [enabledProp];}
                        set { base[enabledProp] = value; }
                }

                protected override ConfigurationPropertyCollection Properties {
                        get { return properties; }
                }

        }

}

#endif
